Changelog
=========

2.0.0 January 26, 2020
----------------------

 - Drop python 2 support
 - Add mypy type checking

1.1.1 January 26, 2020
----------------------

 - Refactor a lot of dependencies and packaging
 - Update dependencies
 - Better python 3 support

1.1.0 May 17, 2016
------------------

Thanks to @rjmackay

- Support mailgun tags
- Officially support python 3
- Switch to CodeClimate test coverage

1.0.0 March 6, 2016
-------------------

Thanks to @fatisar:

- BREAKING: changed initialization to use public/private key
- Update to use mailgun v3 endpoints
- Add several new endpoints
- Update readmes

0.1.7 March 6, 2016
-------------------

- Convert docs to ReStructuredText
- Loosen requests package requirements

0.1.6 March 5, 2016
-------------------

-  Add codeclimate and fix code
-  Add more tests

0.1.5 March 5, 2016
-------------------

-  Minor cleanup

0.1.4 May 3, 2015
-----------------

-  Add tests, monitoring
-  Support campaign\_id

0.1.3 October 1, 2014
---------------------

-  Add ability to send attachments

0.1.2 April 19, 2014
--------------------

-  Fix setup.py
-  Bugfixes

0.1.1 July 17, 2013
-------------------

-  Add setup.py

0.1 July 17, 2013
-----------------

-  Initial Release

